==> foundation-0.0.52.tgz: package/Util/VoxelIDMatrix.js <==
import { DataMatrix } from "./DataMatrix.js";
import { Flat3DIndex } from "@divinevoxel/core/Math/Flat3DIndex";
import { DataTool } from "../Default/Tools/Data/DataTool";
export class VoxelIDMatrix extends DataMatrix {
    size;
    static dataTool = new DataTool();
    index = Flat3DIndex.GetXYZOrder();
    constructor(size) {
        super(size, 0);
        this.size = size;
        this.setBounds(size);
    }
    setBounds(size) {
        this.index.setBounds(size[0], size[1], size[2]);
    }
    toFlatArray() {
        const voxels = [];
        for (const [location, vox] of this.getAll()) {
            const i = this.index.getIndex(location);
            if (typeof vox !== "string") {
                voxels[i] = 0;
                continue;
            }
            voxels[i] = VoxelIDMatrix.dataTool.setStringId(vox).getId();
        }
        return voxels;
    }
    toTypedArray() {
        const length = this.sizeX * this.sizeY * this.sizeZ;
        const voxels = new Uint16Array(length);
        for (const [location, vox] of this.getAll()) {
            const i = this.index.getIndex(location);
            if (typeof vox !== "string") {
                voxels[i] = 0;
                continue;
            }
            voxels[i] = VoxelIDMatrix.dataTool.setStringId(vox).getId();
        }
        return voxels;
    }
    fromFlatArray(voxels) {
        for (const [location, nodeId] of this.getAll()) {
            const rawValue = voxels[this.index.getIndex(location)];
            if (!rawValue) {
                this.setVec3(location, 0);
                continue;
            }
            this.setVec3(location, VoxelIDMatrix.dataTool.setId(rawValue).getStringId());
        }
    }
    copy(matrix) {
        this.setBounds(matrix.size);
        this.setMatrix(matrix.cloneMatrix());
    }
}

==> foundation-0.0.53.tgz: package/Util/VoxelIDMatrix.js <==
import { DataMatrix } from "./DataMatrix.js";
import { Flat3DIndex } from "@amodx/math/Volumes/Indexing/Flat3DIndex.js";
import { DataTool } from "../Default/Tools/Data/DataTool";
export class VoxelIDMatrix extends DataMatrix {
    size;
    static dataTool = new DataTool();
    index = Flat3DIndex.GetXYZOrder();
    constructor(size) {
        super(size, 0);
        this.size = size;
        this.setBounds(size);
    }
    setBounds(size) {
        this.index.setBounds(size[0], size[1], size[2]);
    }
    toFlatArray() {
        const voxels = [];
        for (const [location, vox] of this.getAll()) {
            const i = this.index.getIndexVec3Array(location);
            if (typeof vox !== "string") {
                voxels[i] = 0;
                continue;
            }
            voxels[i] = VoxelIDMatrix.dataTool.setStringId(vox).getId();
        }
        return voxels;
    }
    toTypedArray() {
        const length = this.sizeX * this.sizeY * this.sizeZ;
        const voxels = new Uint16Array(length);
        for (const [location, vox] of this.getAll()) {
            const i = this.index.getIndexVec3Array(location);
            if (typeof vox !== "string") {
                voxels[i] = 0;
                continue;
            }
            voxels[i] = VoxelIDMatrix.dataTool.setStringId(vox).getId();
        }
        return voxels;
    }
    fromFlatArray(voxels) {
        for (const [location, nodeId] of this.getAll()) {
            const rawValue = voxels[this.index.getIndexVec3Array(location)];
            if (!rawValue) {
                this.setVec3(location, 0);
                continue;
            }
            this.setVec3(location, VoxelIDMatrix.dataTool.setId(rawValue).getStringId());
        }
    }
    copy(matrix) {
        this.setBounds(matrix.size);
        this.setMatrix(matrix.cloneMatrix());
    }
}
